##  Managing Automations
Once you've created automations, you can edit, duplicate, deactivate (if active), activate (if inactive), or delete them. To perform these actions, on the Automations page, hover over an automation, click the three-dot button that appears, then select the option that you need.
  * When you deactivate an automation, further actions will not be initiated, but actions in progress are not canceled.
  * When you delete an automation, this action cannot be undone. Instead of deleting an automation, consider deactivating it first.


You can filter automations by owner, status, and fact sheet types. To apply filters, click Add Filter, then select filtering criteria.
